@@ -62,8 +62,8 @@ class Freebox(IPlugin):
 					log.msg("*************  'idx_sec'] <> 1 ****************")
 					# séparation de rs['idx'], nombre   len(maliste)
 					i = 1
-					while i = rs['idx_sec']:
-				#		for i in rs['idx_sec']:
+				#	while i = rs['idx_sec']:
+					for i in rs['idx_sec']:
 							if rs['idx'][i - rang] == '|':
 								rangs.append(rang)
 								log.msg(" rang  :  %s" % (rangs))
